"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AppSeed = exports.devMode = void 0;
const cm_libs_context_aware_logger_1 = require("cm-libs-context-aware-logger");
const cm_libs_utils_1 = require("cm-libs-utils");
const common_1 = require("./common");
class AppSeed {
    name;
    version;
    _devMode = false;
    _terminated = false;
    constructor(name, version, correlator) {
        this.name = name || '';
        this.version = version || '';
        // Setup bootstrap before proceed
        this.bootstrap(correlator);
    }
    bootstrap(correlator) {
        // Catches CTRL+C signal
        process.on('SIGINT', async () => {
            if (!this._terminated) {
                (0, cm_libs_context_aware_logger_1.log)(cm_libs_context_aware_logger_1.Level.CRITICAL, () => `Signal SIGINT is triggered`);
                this._terminated = true;
                await this.shutdown();
            }
        });
        // Listen for TERM signal. E.g. kill
        process.on('SIGTERM', async () => {
            if (!this._terminated) {
                (0, cm_libs_context_aware_logger_1.log)(cm_libs_context_aware_logger_1.Level.CRITICAL, () => `Signal SIGTERM is triggered`);
                this._terminated = true;
                await this.shutdown();
            }
        });
        // Catches SIGUSR1 (10) signal to increase log severity (circled)
        process.on('SIGUSR1', () => {
            cm_libs_context_aware_logger_1.ContextAwareLogger.instance.level = null;
            (0, cm_libs_context_aware_logger_1.log)(cm_libs_context_aware_logger_1.Level.CRITICAL, () => `Logger level: ${cm_libs_context_aware_logger_1.ContextAwareLogger.instance.level}`);
        });
        // Catches uncaught exceptions
        process.on('uncaughtException', async (error, origin) => {
            if (process.stderr.writable) {
                process.stderr.write(`uncaughtException: ${error}, ${origin}\n`);
            }
        });
        // Catches unhandled rejection
        process.on('unhandledRejection', (reason, stack) => {
            if (process.stderr.writable) {
                process.stderr.write(`unhandledRejection: ${reason}, ${stack}\n`);
            }
        });
        process.env.NODE_ENV = common_1.ConfigBase.get('NODE_ENV', (0, cm_libs_utils_1.allowNullOrEmpty)(cm_libs_utils_1.checkString, 'production'));
        this.devMode = exports.devMode = 'production' !== process.env.NODE_ENV;
        // Setup logger
        cm_libs_context_aware_logger_1.ContextAwareLogger.init(common_1.ConfigBase.get('LOG_LEVEL', (0, cm_libs_utils_1.allowNullOrEmpty)((value) => {
            const v = (0, cm_libs_utils_1.checkString)(value);
            return (0, cm_libs_utils_1.isUndefinedOrNull)(cm_libs_context_aware_logger_1.Level[v]) ? cm_libs_context_aware_logger_1.Level.NORMAL : cm_libs_context_aware_logger_1.Level[v];
        })), correlator);
    }
    get devMode() {
        return this._devMode;
    }
    set devMode(value) {
        this._devMode = value;
    }
}
exports.AppSeed = AppSeed;
//# sourceMappingURL=app-seed.js.map