"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BasePubSub = void 0;
const cm_libs_context_aware_error_1 = require("cm-libs-context-aware-error");
const cm_libs_context_aware_logger_1 = require("cm-libs-context-aware-logger");
const graphql_redis_subscriptions_1 = require("graphql-redis-subscriptions");
const ioredis_1 = __importDefault(require("ioredis"));
class BasePubSub {
    REDIS_URL;
    REDIS_HOST;
    REDIS_PORT;
    redis;
    constructor(params = {}) {
        const { REDIS_URL, REDIS_HOST, REDIS_PORT } = params;
        this.REDIS_URL = REDIS_URL;
        this.REDIS_HOST = REDIS_HOST;
        this.REDIS_PORT = REDIS_PORT;
        if (!this.REDIS_URL && !this.REDIS_HOST) {
            (0, cm_libs_context_aware_error_1.throwError)('9999', 'Must provide either 1 Host or URL');
        }
        try {
            if (this.REDIS_URL) {
                this.redis = new graphql_redis_subscriptions_1.RedisPubSub({
                    publisher: new ioredis_1.default(this.REDIS_URL),
                    subscriber: new ioredis_1.default(this.REDIS_URL)
                });
            }
            else {
                if (!this.REDIS_PORT && !this.REDIS_HOST) {
                    (0, cm_libs_context_aware_error_1.throwError)('9999', 'Must provide both Host and Port');
                }
                const options = {
                    host: this.REDIS_HOST,
                    port: this.REDIS_PORT,
                    retryStrategy: (times) => {
                        // reconnect after
                        return Math.min(times * 50, 2000);
                    }
                };
                this.redis = new graphql_redis_subscriptions_1.RedisPubSub({
                    publisher: new ioredis_1.default(options),
                    subscriber: new ioredis_1.default(options)
                });
            }
        }
        catch (err) {
            (0, cm_libs_context_aware_logger_1.log)(cm_libs_context_aware_logger_1.Level.ERROR, () => `BasePubSub Err: ${JSON.stringify(err, null, 2)}`);
        }
    }
    async term() {
        await this.redis.close();
    }
}
exports.BasePubSub = BasePubSub;
//# sourceMappingURL=pubsub.js.map