"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.baseHandler = void 0;
const cm_libs_context_aware_error_1 = require("cm-libs-context-aware-error");
const cm_libs_context_aware_logger_1 = require("cm-libs-context-aware-logger");
const error_1 = require("../error");
async function baseHandler(thisObject, fn, schema, request, info) {
    try {
        (0, cm_libs_context_aware_logger_1.log)(cm_libs_context_aware_logger_1.Level.DETAIL, () => `fn(${fn.name}) => Start`);
        const { error, value } = schema.validate(request, { stripUnknown: true });
        if (error) {
            (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.INVALID_PARAMETER, error.message, {
                function: fn.name,
                details: error.details,
                text: { input: error.details?.[0]?.context?.peers || error.details?.[0]?.context?.key }
            });
        }
        return await fn.apply(thisObject, [value, info]);
    }
    catch (error) {
        if (!error_1.ErrorHandler.isEnabled) {
            (0, cm_libs_context_aware_error_1.throwFromError)(error);
        }
        const { code, message, statusCode } = await error_1.ErrorHandler.translate(error, error.statusCode, info?.headers?.localeCode);
        const params = {
            ...error.params,
            statusCode
        };
        (0, cm_libs_context_aware_error_1.throwError)(code, message, params, false, error.stack);
    }
}
exports.baseHandler = baseHandler;
//# sourceMappingURL=validator.js.map